@@ -1,8 +1,8 @@
-/* ecc-384.c.c
+/* ecc-384.c
 
    Compile time constant (but machine dependent) tables.
 
-   Copyright (C) 2013 Niels Möller
+   Copyright (C) 2013, 2014 Niels Möller
 
    This file is part of GNU Nettle.
 
@@ -39,6 +39,7 @@
 
 #include <assert.h>
 
+#include "ecc.h"
 #include "ecc-internal.h"
 
 #define USE_REDC 0
@@ -48,7 +49,7 @@
 #if HAVE_NATIVE_ecc_384_modp
 #define ecc_384_modp nettle_ecc_384_modp
 void
-ecc_384_modp (const struct ecc_curve *ecc, mp_limb_t *rp);
+ecc_384_modp (const struct ecc_modulo *m, mp_limb_t *rp);
 #elif GMP_NUMB_BITS == 32
 
 /* Use that 2^{384} = 2^{128} + 2^{96} - 2^{32} + 1, and eliminate 256
@@ -61,7 +62,7 @@ ecc_384_modp (const struct ecc_curve *ecc, mp_limb_t *rp);
    almost 8 at a time. Do only 7, to avoid additional carry
    propagation, followed by 5. */
 static void
-ecc_384_modp (const struct ecc_curve *ecc, mp_limb_t *rp)
+ecc_384_modp (const struct ecc_modulo *p, mp_limb_t *rp)
 {
   mp_limb_t cy, bw;
 
@@ -98,14 +99,14 @@ ecc_384_modp (const struct ecc_curve *ecc, mp_limb_t *rp)
   assert (cy >= bw);
   cy -= bw;
   assert (cy <= 1);
-  cy = cnd_add_n (cy, rp, ecc->Bmodp, ECC_LIMB_SIZE);
+  cy = cnd_add_n (cy, rp, p->B, ECC_LIMB_SIZE);
   assert (cy == 0);
 }
 #elif GMP_NUMB_BITS == 64
 /* p is 6 limbs, and B^6 - p = B^2 + 2^32 (B - 1) + 1. Eliminate 3
    (almost 4) limbs at a time. */
 static void
-ecc_384_modp (const struct ecc_curve *ecc, mp_limb_t *rp)
+ecc_384_modp (const struct ecc_modulo *p, mp_limb_t *rp)
 {
   mp_limb_t tp[6];
   mp_limb_t cy;
@@ -139,39 +140,71 @@ ecc_384_modp (const struct ecc_curve *ecc, mp_limb_t *rp)
   cy = sec_add_1 (rp + 5, rp + 5, 1, cy);
   assert (cy <= 1);
 
-  cy = cnd_add_n (cy, rp, ecc->Bmodp, ECC_LIMB_SIZE);
+  cy = cnd_add_n (cy, rp, p->B, ECC_LIMB_SIZE);
   assert (cy == 0);  
 }
 #else
-#define ecc_384_modp ecc_generic_modp
+#define ecc_384_modp ecc_mod
 #endif
   
 const struct ecc_curve nettle_secp_384r1 =
 {
-  384,
-  ECC_LIMB_SIZE,    
-  ECC_BMODP_SIZE,
-  ECC_BMODQ_SIZE,
+  {
+    384,
+    ECC_LIMB_SIZE,    
+    ECC_BMODP_SIZE,
+    ECC_REDC_SIZE,
+    ECC_MOD_INV_ITCH (ECC_LIMB_SIZE),
+    0,
+
+    ecc_p,
+    ecc_Bmodp,
+    ecc_Bmodp_shifted,
+    ecc_redc_ppm1,
+    ecc_pp1h,
+
+    ecc_384_modp,
+    ecc_384_modp,
+    ecc_mod_inv,
+    NULL,
+  },
+  {
+    384,
+    ECC_LIMB_SIZE,    
+    ECC_BMODQ_SIZE,
+    0,
+    ECC_MOD_INV_ITCH (ECC_LIMB_SIZE),
+    0,
+
+    ecc_q,
+    ecc_Bmodq,
+    ecc_Bmodq_shifted,
+    NULL,
+    ecc_qp1h,
+
+    ecc_mod,
+    ecc_mod,
+    ecc_mod_inv,
+    NULL,
+  },
+
   USE_REDC,
-  ECC_REDC_SIZE,
   ECC_PIPPENGER_K,
   ECC_PIPPENGER_C,
-  ecc_p,
+
+  ECC_ADD_JJJ_ITCH (ECC_LIMB_SIZE),
+  ECC_MUL_A_ITCH (ECC_LIMB_SIZE),
+  ECC_MUL_G_ITCH (ECC_LIMB_SIZE),
+  ECC_J_TO_A_ITCH (ECC_LIMB_SIZE),
+
+  ecc_add_jjj,
+  ecc_mul_a,
+  ecc_mul_g,
+  ecc_j_to_a,
+
   ecc_b,
-  ecc_q,
   ecc_g,
-  ecc_redc_g,
-  ecc_384_modp,
-  ECC_REDC_SIZE != 0 ? ecc_generic_redc : NULL,
-  ecc_384_modp,
-  ecc_generic_modq,
-  ecc_Bmodp,
-  ecc_Bmodp_shifted,
-  ecc_pp1h,
-  ecc_redc_ppm1,
+  NULL,
   ecc_unit,
-  ecc_Bmodq,
-  ecc_Bmodq_shifted,
-  ecc_qp1h,
   ecc_table
 };
