@@ -1,4 +1,5 @@
 #include "testutils.h"
+#include "nettle-internal.h"
 #include "nettle-meta.h"
 
 const char* hashes[] = {
@@ -10,10 +11,14 @@ const char* hashes[] = {
   "sha224",
   "sha256",
   "sha384",
-  "sha512"
+  "sha512",
+  "sha3_224",
+  "sha3_256",
+  "sha3_384",
+  "sha3_512",
 };
 
-int
+void
 test_main(void)
 {
   int i,j;
@@ -29,6 +34,7 @@ test_main(void)
   while (NULL != nettle_hashes[j])
     j++;
   ASSERT(j == count); /* we are not missing testing any hashes */
-  SUCCESS();
+  for (j = 0; NULL != nettle_hashes[j]; j++)
+    ASSERT(nettle_hashes[j]->digest_size <= NETTLE_MAX_HASH_DIGEST_SIZE);
 }
   
